@@ -4,7 +4,7 @@ use 5.005;
 use base qw(Module::Install::Base);
 use strict;
 
-our $VERSION = '0.007';
+our $VERSION = '0.008';
 our $AUTHOR_ONLY = 1;
 
 sub rdf_metadata
@@ -13,6 +13,14 @@ sub rdf_metadata
 	$self->admin->rdf_metadata(@_) if $self->is_admin;
 }
 
+sub write_meta_ttl
+{
+	my $self = shift;
+	my $file = shift || "META.ttl";
+	$self->admin->write_meta_ttl($file) if $self->is_admin;
+	$self->clean_files($file);
+}
+
 1;
 
 __END__
@@ -24,15 +32,17 @@ Module::Install::RDF - advanced metadata for your distribution
 
 In Makefile.PL:
 
-  rdf_metadata;
+  rdf_metadata;     # reads "meta/*"
+  write_meta_ttl;   # writes "META.ttl"
 
 =head1 DESCRIPTION
 
 This module doesn't really do much on its own, but is a pre-requisite for 
 L<Module::Install::DOAP>.
 
-Specifically, it reads all the RDF it can find in the distribution's 'meta'
-directory and exposes it for other modules to make use of.
+Specifically, it reads all the RDF it can find in the distribution's "meta"
+directory and exposes it for other modules to make use of. It also allows you
+to write out a combined graph using Turtle.
 
 =head1 BUGS
 
@@ -52,9 +62,15 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2012 by Toby Inkster
+Copyright (C) 2011-2013 by Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
 =cut
